==> pass_mtx-0.0.22.tar.gz: ios/Classes/PassMtxPlugin.m <==
#import "PassMtxPlugin.h"

#import "pass_mtx_ios.h"

@implementation PassMtxPlugin

PassMtxIOSWrapper *_passWrapper;

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"pass_mtx"
            binaryMessenger:[registrar messenger]];
  PassMtxPlugin* instance = [[PassMtxPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];

  _passWrapper = [[PassMtxIOSWrapper alloc] init];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  NSLog(@"Handle Method %@",call.method);
  if ([@"getPassVersion" isEqualToString:call.method]) {
    result([_passWrapper getDLLVersion]);
  } else if ([@"passStageInit" isEqualToString:call.method]) {
    NSString* app_id = call.arguments[@"app_id"];
    NSString* client_id = call.arguments[@"client_id"];
    NSString* private_pem = call.arguments[@"private_pem"];
    NSString* public_pem = call.arguments[@"public_pem"];

    result([_passWrapper passStageInit:app_id client_id:client_id private_pem:private_pem public_pem:public_pem]);
  } else if ([@"getPassPing" isEqualToString:call.method]) {
    result([_passWrapper ping]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else 
  if ([@"getCard" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];

    result([_passWrapper PassGetCard:user_id]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else 
  if ([@"deleteCard" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];

    result([_passWrapper PassDeleteCard:user_id]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else 
  if ([@"saveCard" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* card_pan = call.arguments[@"card_pan"];
    NSString* cvv = call.arguments[@"cvv"];
    NSString* exp_date = call.arguments[@"exp_date"];
    NSString* card_holder_name = call.arguments[@"card_holder_name"];

    result([_passWrapper PassSaveCard:user_id card_pan:card_pan cvv:cvv exp_date:exp_date card_holder_name:card_holder_name]);
  } 
  else 
  if ([@"verifyCard" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* verification_method = call.arguments[@"verification_method"];
    NSString* verification_value = call.arguments[@"verification_value"];

    result([_passWrapper PassVerifyCard:user_id verification_method:verification_method verification_value:verification_value]);
  } 
  else 
  if ([@"passInit" isEqualToString:call.method]) {
    NSString* app_id = call.arguments[@"app_id"];
    NSString* client_id = call.arguments[@"client_id"];
    NSString* private_pem = call.arguments[@"private_pem"];
    NSString* public_pem = call.arguments[@"public_pem"];

    result([_passWrapper passInit:app_id client_id:client_id private_pem:private_pem public_pem:public_pem]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else 
  if ([@"purchase" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* order_id = call.arguments[@"order_id"];
    NSString* payment_token = call.arguments[@"payment_token"];
    NSString* payment_amount = call.arguments[@"payment_amount"];
    NSString* expire_date = call.arguments[@"expire_date"];
    NSString* db_ref_no = call.arguments[@"db_ref_no"];
    NSString* description = call.arguments[@"description"];

    result([_passWrapper PassPurchase:user_id order_id:order_id payment_token:payment_token payment_amount:payment_amount expire_date:expire_date db_ref_no:db_ref_no description:description]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else 
  if ([@"getQr" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* order_id = call.arguments[@"order_id"];
    NSString* payment_token = call.arguments[@"payment_token"];
    NSString* exp_date = call.arguments[@"exp_date"];
    NSString* ttl = call.arguments[@"ttl"];

    result([_passWrapper PassGetQr :user_id order_id:order_id payment_token:payment_token expire_date:exp_date ttl:ttl ]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else 
  if ([@"orderEnquery" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* order_id = call.arguments[@"order_id"];

    result([_passWrapper PassOrderInquery:user_id order_id:order_id]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else 
  if ([@"orderCancel" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* order_id = call.arguments[@"order_id"];

    result([_passWrapper PassOrderCancel:user_id order_id:order_id]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else 
  if ([@"orderConfirm" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* order_id = call.arguments[@"order_id"];
    NSString* confirm_method = call.arguments[@"confirm_method"];
    NSString* confirm_result = call.arguments[@"confirm_result"];
    NSString* payment_token = call.arguments[@"payment_token"];
    NSString* expire_date = call.arguments[@"expire_date"];

    result([_passWrapper PassOrderConfirm:user_id order_id:order_id confirm_method:confirm_method confirm_result:confirm_result payment_token:payment_token expire_date:expire_date ]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else {
    
    result(FlutterMethodNotImplemented);
  }
}

@end

==> pass_mtx-0.0.23.tar.gz: ios/Classes/PassMtxPlugin.m <==
#import "PassMtxPlugin.h"

#import "pass_mtx_ios.h"

@implementation PassMtxPlugin

PassMtxIOSWrapper *_passWrapper;

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"pass_mtx"
            binaryMessenger:[registrar messenger]];
  PassMtxPlugin* instance = [[PassMtxPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];

  _passWrapper = [[PassMtxIOSWrapper alloc] init];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  NSLog(@"Handle Method %@",call.method);
  if ([@"getPassVersion" isEqualToString:call.method]) {
    result([_passWrapper getDLLVersion]);
  } else if ([@"passStageInit" isEqualToString:call.method]) {
    NSString* app_id = call.arguments[@"app_id"];
    NSString* client_id = call.arguments[@"client_id"];
    NSString* private_pem = call.arguments[@"private_pem"];
    NSString* public_pem = call.arguments[@"public_pem"];

    result([_passWrapper passStageInit:app_id client_id:client_id private_pem:private_pem public_pem:public_pem]);
  } else if ([@"getPassPing" isEqualToString:call.method]) {
    result([_passWrapper ping]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else 
  if ([@"getCard" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];

    result([_passWrapper PassGetCard:user_id]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else 
  if ([@"deleteCard" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* card_ref = call.arguments[@"card_ref"];

    result([_passWrapper PassDeleteCard:user_id card_ref:card_ref]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else 
  if ([@"saveCard" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* card_pan = call.arguments[@"card_pan"];
    NSString* cvv = call.arguments[@"cvv"];
    NSString* exp_date = call.arguments[@"exp_date"];
    NSString* card_holder_name = call.arguments[@"card_holder_name"];

    result([_passWrapper PassSaveCard:user_id card_pan:card_pan cvv:cvv exp_date:exp_date card_holder_name:card_holder_name]);
  } 
  else 
  if ([@"verifyCard" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* verification_method = call.arguments[@"verification_method"];
    NSString* verification_value = call.arguments[@"verification_value"];

    result([_passWrapper PassVerifyCard:user_id verification_method:verification_method verification_value:verification_value]);
  } 
  else 
  if ([@"passInit" isEqualToString:call.method]) {
    NSString* app_id = call.arguments[@"app_id"];
    NSString* client_id = call.arguments[@"client_id"];
    NSString* private_pem = call.arguments[@"private_pem"];
    NSString* public_pem = call.arguments[@"public_pem"];

    result([_passWrapper passInit:app_id client_id:client_id private_pem:private_pem public_pem:public_pem]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else 
  if ([@"purchase" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* order_id = call.arguments[@"order_id"];
    NSString* payment_token = call.arguments[@"payment_token"];
    NSString* payment_amount = call.arguments[@"payment_amount"];
    NSString* expire_date = call.arguments[@"expire_date"];
    NSString* db_ref_no = call.arguments[@"db_ref_no"];
    NSString* description = call.arguments[@"description"];

    result([_passWrapper PassPurchase:user_id order_id:order_id payment_token:payment_token payment_amount:payment_amount expire_date:expire_date db_ref_no:db_ref_no description:description]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else 
  if ([@"getQr" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* order_id = call.arguments[@"order_id"];
    NSString* payment_token = call.arguments[@"payment_token"];
    NSString* exp_date = call.arguments[@"exp_date"];
    NSString* ttl = call.arguments[@"ttl"];

    result([_passWrapper PassGetQr :user_id order_id:order_id payment_token:payment_token expire_date:exp_date ttl:ttl ]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else 
  if ([@"orderEnquery" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* order_id = call.arguments[@"order_id"];

    result([_passWrapper PassOrderInquery:user_id order_id:order_id]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else 
  if ([@"orderCancel" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* order_id = call.arguments[@"order_id"];

    result([_passWrapper PassOrderCancel:user_id order_id:order_id]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else 
  if ([@"orderConfirm" isEqualToString:call.method]) {
    NSString* user_id = call.arguments[@"user_id"];
    NSString* order_id = call.arguments[@"order_id"];
    NSString* confirm_method = call.arguments[@"confirm_method"];
    NSString* confirm_result = call.arguments[@"confirm_result"];
    NSString* payment_token = call.arguments[@"payment_token"];
    NSString* expire_date = call.arguments[@"expire_date"];

    result([_passWrapper PassOrderConfirm:user_id order_id:order_id confirm_method:confirm_method confirm_result:confirm_result payment_token:payment_token expire_date:expire_date ]);
    // result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } 
  else {
    
    result(FlutterMethodNotImplemented);
  }
}

@end
